<h1></h1>
<p>
<p></p><div class="separator" style="clear: both; text-align: center;"><div class="separator" style="clear: both; text-align: center;"><a href="" style="margin-left: 1em; margin-right: 1em;"><img border="0" data-original-height="auto" data-original-width="auto" height="auto" src="https://images.payhip.com/o_1fs1h9o181o2k1pn4ij2mga1anum.png" width="1" /></a></div><br /><a href="https://payhip.com/b/AlZBY" rel="" style="margin-left: 1em; margin-right: 1em;"><img border="0" data-original-height="Auto" data-original-width="Auto" src="https://images.payhip.com/o_1fs1gqvos13krrluavn1vf81hiam.jpeg" /></a></div><br />&nbsp;<br /><br /><p></p>

# bulk file renamer mac
```bash
pip3 bulk file renamer mac